# Changelog

## [0.1.6a1](https://github.com/OpenVoiceOS/OVOS-workshop/tree/0.1.6a1) (2024-10-14)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/0.1.5...0.1.6a1)

**Merged pull requests:**

- fix:finish extracting intent classes from adapt package [\#248](https://github.com/OpenVoiceOS/OVOS-workshop/pull/248) ([JarbasAl](https://github.com/JarbasAl))



\* *This Changelog was automatically generated by [github_changelog_generator](https://github.com/github-changelog-generator/github-changelog-generator)*
